@@ -76,6 +76,7 @@ class LinkInventModel(GenerativeModelBase):
         log_probs = logits.log_softmax(dim=2).transpose(1, 2)  # (batch, voc, seq - 1)
         return self._nll_loss(log_probs, linker_seqs[:, 1:]).sum(dim=1)  # (batch)
 
+    @torch.no_grad()
     def sample(self, inputs, input_seq_lengths) -> List[SampledSequencesDTO]:
         """
         Samples as many linker as warhead pairs in the tensor.
@@ -85,7 +86,8 @@ class LinkInventModel(GenerativeModelBase):
         """
         batch_size = inputs.size(0)
 
-        input_vector = torch.full((batch_size, 1), self.vocabulary.output.vocabulary["^"], dtype=torch.long).cuda() # (batch, 1)
+        input_vector = torch.full((batch_size, 1), self.vocabulary.target.vocabulary["^"],
+                                  dtype=torch.long).cuda()  # (batch, 1)
         seq_lengths = torch.ones(batch_size)  # (batch)
         encoder_padded_seqs, hidden_states = self.network.forward_encoder(inputs, input_seq_lengths)
         nlls = torch.zeros(batch_size).cuda()
@@ -103,11 +105,12 @@ class LinkInventModel(GenerativeModelBase):
             if not_finished.sum() == 0:
                 break
 
-        linker_smiles_list = [self.vocabulary.output.decode(seq) for seq in torch.cat(sequences, 1).data.cpu().numpy()]
+        linker_smiles_list = [self.vocabulary.target.decode(seq) for seq in torch.cat(sequences, 1).data.cpu().numpy()]
         warheads_smiles_list = [self.vocabulary.input.decode(seq) for seq in inputs.data.cpu().numpy()]
 
         result = [SampledSequencesDTO(warheads, linker, nll) for warheads, linker, nll in
                   zip(warheads_smiles_list, linker_smiles_list, nlls.data.cpu().numpy().tolist())]
         return result
 
-
+    def get_network_parameters(self):
+        return self.network.parameters()
